@@ -28,6 +28,10 @@ try:
     # EGG files.
     #
     for entrypoint in pkg_resources.iter_entry_points('coopr.opt'):
-        plugin_class = entrypoint.load()
+        try:
+            plugin_class = entrypoint.load()
+        except Exception, err:
+            print "Error loading coopr.opt entry point:", str(err),' entrypoint="%s"' % str(entrypoint)
 except Exception, err:
-    print "Error loading coopr.opt entry points:",str(err),' entrypoint="%s"' % str(entrypoint)
+    print "Error loading coopr.opt entry points"
+
