@@ -28,5 +28,5 @@ class AbstractProblemWriter(ManagedPlugin):
         ManagedPlugin.__init__(self)
         self.format=problem_format
 
-    def __call__(self, model, filename): #pragma:nocover
+    def __call__(self, model, filename, solver_capability): #pragma:nocover
         raise TypeError, "Method __call__ undefined in writer for format "+str(self.format)
